Author: sms
Date: Fri Jan 16 17:46:50 2009
New Revision: 735204

URL: http://svn.apache.org/viewvc?rev=735204&view=rev
Log:
PIG-623: Fix spelling errors in output messages (tomwhite)

Modified:
    hadoop/pig/trunk/CHANGES.txt
    hadoop/pig/trunk/src/org/apache/pig/Main.java
    hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/schema/Schema.java
    
hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/validators/TypeCheckingVisitor.java

Modified: hadoop/pig/trunk/CHANGES.txt
URL: 
http://svn.apache.org/viewvc/hadoop/pig/trunk/CHANGES.txt?rev=735204&r1=735203&r2=735204&view=diff
==============================================================================
--- hadoop/pig/trunk/CHANGES.txt (original)
+++ hadoop/pig/trunk/CHANGES.txt Fri Jan 16 17:46:50 2009
@@ -361,3 +361,5 @@
        PIG-599: Added buffering to BufferedPositionedInputStream (gates)
 
     PIG-597: Fix for how * is treated by UDFs (shravanmn via olgan)
+
+    PIG-623: Fix spelling errors in output messages (tomwhite via sms)

Modified: hadoop/pig/trunk/src/org/apache/pig/Main.java
URL: 
http://svn.apache.org/viewvc/hadoop/pig/trunk/src/org/apache/pig/Main.java?rev=735204&r1=735203&r2=735204&view=diff
==============================================================================
--- hadoop/pig/trunk/src/org/apache/pig/Main.java (original)
+++ hadoop/pig/trunk/src/org/apache/pig/Main.java Fri Jan 16 17:46:50 2009
@@ -231,7 +231,7 @@
             substFile = file + ".substituted";
             pin = runParamPreprocessor(in, params, paramFiles, substFile, 
debug || dryrun);
             if (dryrun){
-                log.info("Dry run completed. Substitued pig script is at " + 
substFile);
+                log.info("Dry run completed. Substituted pig script is at " + 
substFile);
                 return;
             }
 
@@ -295,7 +295,7 @@
             substFile = remainders[0] + ".substituted";
             pin = runParamPreprocessor(in, params, paramFiles, substFile, 
debug || dryrun);
             if (dryrun){
-                log.info("Dry run completed. Substitued pig script is at " + 
substFile);
+                log.info("Dry run completed. Substituted pig script is at " + 
substFile);
                 return;
             }
 

Modified: 
hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/schema/Schema.java
URL: 
http://svn.apache.org/viewvc/hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/schema/Schema.java?rev=735204&r1=735203&r2=735204&view=diff
==============================================================================
--- hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/schema/Schema.java 
(original)
+++ hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/schema/Schema.java 
Fri Jan 16 17:46:50 2009
@@ -459,7 +459,7 @@
         *   1) if either one has a type null or unknown and other has a type 
OTHER THAN
         *   null or unknown, the result type will be the latter non 
null/unknown type
         *   2) If either type is bytearray, then result type will be the other 
(possibly non BYTEARRAY) type
-        *   3) If current type can be casted to the other type, then the 
result type will be the
+        *   3) If current type can be cast to the other type, then the result 
type will be the
         *   other type 
         * @return the prefix merged field schema this can be null. 
         *
@@ -1434,7 +1434,7 @@
      *   1) if either one has a type null or unknown and other has a type 
OTHER THAN
      *   null or unknown, the result type will be the latter non null/unknown 
type
      *   2) If either type is bytearray, then result type will be the other 
(possibly  non BYTEARRAY) type
-     *   3) If current type can be casted to the other type, then the result 
type will be the
+     *   3) If current type can be cast to the other type, then the result 
type will be the
      *   other type 
      * @return the prefix merged schema this can be null if one schema is null 
and
      *         allowIncompatibleTypes is true

Modified: 
hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/validators/TypeCheckingVisitor.java
URL: 
http://svn.apache.org/viewvc/hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/validators/TypeCheckingVisitor.java?rev=735204&r1=735203&r2=735204&view=diff
==============================================================================
--- 
hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/validators/TypeCheckingVisitor.java
 (original)
+++ 
hadoop/pig/trunk/src/org/apache/pig/impl/logicalLayer/validators/TypeCheckingVisitor.java
 Fri Jan 16 17:46:50 2009
@@ -1390,7 +1390,7 @@
      * one of the funcSpecs and the input schema s. Here first exact match
      * for all non byte array fields is first attempted and if there is
      * exactly one candidate, it is chosen (since the bytearray(s) can
      * just be casted to corresponding type(s) in the candidate)
      * @param funcSpecs - mappings provided by udf
      * @param s - input schema
      * @param func - LOUserfunc for which matching is requested
@@ -3081,7 +3081,7 @@
         String originalTypeName = DataType.findTypeName(originalType) ;
         String toTypeName = DataType.findTypeName(toType) ;
         String opName = op.getClass().getSimpleName() ;
-        msgCollector.collect(originalTypeName + " is implicitly casted to "
+        msgCollector.collect(originalTypeName + " is implicitly cast to "
                              + toTypeName +" under " + opName + " Operator",
                              MessageType.Warning) ;
     }
@@ -1390,7 +1390,7 @@
      * for all non byte array fields is first attempted and if there is
      * exactly one candidate, it is chosen (since the bytearray(s) can
-     * just be casted to corresponding type(s) in the candidate)
+     * just be cast to corresponding type(s) in the candidate)
      * @param funcSpecs - mappings provided by udf
      * @param s - input schema


Reply via email to